/**
 *
 * Id:
 *  $Id: JAASHelper.java,v 1.1.26.2 2010/03/19 17:19:00 team1 Exp $
 *
 * Revision:
 *  $Revision: 1.1.26.2 $
 *
 * Log:
 *  $Log: JAASHelper.java,v $
 *  Revision 1.1.26.2  2010/03/19 17:19:00  team1
 *  (found during testing for FS#15447 - JBoss 5/Pinnacle Pro: Update to JBoss 5)
 *  Incorrect role name "PinnacleUser" was being used in the ActiveDataManagerSession
 *  This is actually the client-side login module name, and only happens to be similar to the role name "pinnacleuser".
 *  This was only working because we manually created "PinnacleUser" entries in the userroles table.
 *  Fixed, and commented code in JAASHelper (where "PinnacleUser" is actually used) to clarify the difference.
 *  - RL & AS
 *
 *  Revision 1.1.26.1  2010/03/17 10:56:35  team1
 *  FS#15447 - JBoss 5/Pinnacle Pro: Update to JBoss 5
 *  Changed to use SecurityClient instead of LoginContext.
 *  This allows us to validate all threads to be used for logging in; the previous code would allow only the current thread to be authenticated when run against JBoss 5.
 *  - RL & AS
 *
 *  Revision 1.1  2005/07/20 14:12:26  tony
 *  JAASHelper class added to allow app wide usage of Authentication protocol.
 *
 *
 */

package com.actual_systems.web.test;

import org.jboss.security.client.SecurityClient;
import org.jboss.security.client.SecurityClientFactory;

import javax.security.auth.callback.Callback;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.callback.NameCallback;
import javax.security.auth.callback.PasswordCallback;
import javax.security.auth.callback.UnsupportedCallbackException;
import javax.security.auth.login.LoginException;

/**
 * Helper class to deal with JAAS authentication details.
 *
 * @author tony
 * @version $Revision: 1.1.26.2 $
 */

public class JAASHelper_s {

    /**
     * @param authConfEntry Module to use in auth.conf for login. Not related to server-side login roles!
     * @param name
     * @param passwd
     * @throws javax.security.auth.login.LoginException
     */
    public static SecurityClient login(String authConfEntry, String name, String passwd) throws LoginException {
        System.out.println("login(" + authConfEntry + "," + name + "," + passwd + ")");

        char[] password = passwd.toCharArray();

        try {
            CallbackHandler handler = new AppCallbackHandler(name, password);
            SecurityClient client = SecurityClientFactory.getSecurityClient();
            client.setVmwideAssociation(true);
            client.setJAAS(authConfEntry, handler);
            client.login();
            return client;
        } catch (Exception e) {
            e.printStackTrace();
            throw new LoginException(e.getMessage());
        }

    }

    /**
     *
     */
    public static class AppCallbackHandler implements CallbackHandler {
        private String username;
        private char[] password;

        /**
         *
         * @param username
         * @param password
         */
        public AppCallbackHandler(String username, char[] password) {
            this.username = username;
            this.password = password;
        }

        /**
         *
         * @param callbacks
         * @throws java.io.IOException
         * @throws javax.security.auth.callback.UnsupportedCallbackException
         */
        public void handle(Callback[] callbacks) throws
                java.io.IOException, UnsupportedCallbackException {

            System.out.println("handle(" + callbacks + ")");

            for (int i = 0; i < callbacks.length; i++) {

                Callback callback = callbacks[i];

                System.out.println("callback " + i + " : " + callback);

                if (callback instanceof NameCallback) {
                    NameCallback nc = (NameCallback) callback;
                    nc.setName(username);
                } else if (callback instanceof PasswordCallback) {
                    PasswordCallback pc = (PasswordCallback) callback;
                    pc.setPassword(password);
                } else {
                    throw new UnsupportedCallbackException(callback, "Unrecognized Callback");
                }
            }
        }
    }


}